# Generated by Django 4.2.28 on 2026-02-23 09:58

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cookie_optin", "0005_cookie_path_empty_string_then_no_null"),
    ]

    operations = [
        migrations.CreateModel(
            name="DailyConsentStats",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("date", models.DateField(unique=True, verbose_name="Date")),
                (
                    "accept_count",
                    models.PositiveIntegerField(default=0, verbose_name="Accepts"),
                ),
                (
                    "decline_count",
                    models.PositiveIntegerField(default=0, verbose_name="Declines"),
                ),
                (
                    "save_count",
                    models.PositiveIntegerField(
                        default=0, verbose_name="Saves (custom)"
                    ),
                ),
            ],
            options={
                "verbose_name": "Daily consent stats",
                "verbose_name_plural": "Daily consent stats",
                "ordering": ["-date"],
            },
        ),
    ]
