{% load static %}

<link rel="stylesheet" href="{% static 'cookie_optin/cookie_optin.css' %}">
<script defer type="text/javascript" src="{% url 'cookie_optin:config' %}"></script>
<script defer type="text/javascript" data-no-auto-load src="{% static 'cookie_optin/klaro-0.7.22.js' %}"></script>
<script defer type="text/javascript" src="{% static 'cookie_optin/klaro-init.js' %}"></script>
