# Generated by Django 5.2.11 on 2026-02-23 09:23

# Django
import django.db.models.deletion
from django.db import migrations, models

# Third party
import parler.fields


class Migration(migrations.Migration):

    dependencies = [
        ('cookie_optin', '0003_no_consent'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='application',
            options={'ordering': ['order'], 'verbose_name': 'Application', 'verbose_name_plural': 'Applications'},
        ),
        migrations.AlterModelOptions(
            name='purpose',
            options={'ordering': ['order'], 'verbose_name': 'Purpose', 'verbose_name_plural': 'Purposes'},
        ),
        migrations.AddField(
            model_name='application',
            name='order',
            field=models.IntegerField(default=0, verbose_name='Order'),
        ),
        migrations.AddField(
            model_name='purpose',
            name='order',
            field=models.IntegerField(default=0, verbose_name='Order'),
        ),
        migrations.AlterField(
            model_name='application',
            name='no_consent',
            field=models.BooleanField(default=False, help_text='The application will load even before the user gave explicit consent. Use only if the application does not collect user data.', verbose_name='Do not need consent'),
        ),
        migrations.AlterField(
            model_name='applicationtranslation',
            name='master',
            field=parler.fields.TranslationsForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='cookie_optin.application'),
        ),
        migrations.AlterField(
            model_name='purposetranslation',
            name='master',
            field=parler.fields.TranslationsForeignKey(editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='translations', to='cookie_optin.purpose'),
        ),
    ]
